@@ -1,6 +1,6 @@
 __title__ = 'dash.models'
 __author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
-__copyright__ = 'Copyright (c) 2013 Artur Barseghyan'
+__copyright__ = 'Copyright (c) 2013-2014 Artur Barseghyan'
 __license__ = 'GPL 2.0/LGPL 2.1'
 __all__ = ('DashboardSettings', 'DashboardWorkspace', 'DashboardEntry', 'DashboardPlugin')
 
@@ -10,13 +10,14 @@ logger = logging.getLogger(__name__)
 from django.core.urlresolvers import reverse
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
-from django.contrib.auth.models import User, Group
+from django.contrib.auth.models import Group
 
 from autoslug import AutoSlugField
 
 from dash.base import plugin_registry, get_registered_plugins, get_registered_layouts
 from dash.helpers import slugify_workspace
 from dash.fields import OrderField
+from dash.compat import User
 
 class DashboardSettings(models.Model):
     """
